@@ -1,4 +1,4 @@
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 import os
 from os import listdir
 from os.path import isfile, join, exists
@@ -48,7 +48,7 @@ def main():
     if ".zip" not in bdreportszip:
         print("Its not a zip file", bdreportszip, fg="red")
         sys.exit()
-    this_dir = Path(globals().get("__file__", bdreportszip)).absolute().parent
+    this_dir = os.path.abspath(bdreportszip)
     filelocation = ""
 
     if "\\" in bdreportszip or "/" in bdreportszip:
